@@ -59,6 +59,11 @@ void sp_gcdist(double *lon1, double *lon2, double *lat1, double *lat2,
     a = 6378.137;              /* WGS-84 equatorial radius in km */
     f = 1.0/298.257223563;     /* WGS-84 ellipsoid flattening factor */
     
+    if ((fabs(lon1[0] - lon2[0]) < DOUBLE_EPS) &&
+        (fabs(lat1[0] - lat2[0]) < DOUBLE_EPS)) {
+        dist[0] = 0.0;
+        return;
+    }
     lat1R = lat1[0]*DE2RA;
     lat2R = lat2[0]*DE2RA;
     lon1R = lon1[0]*DE2RA;
